==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressControllerSpecBuilder extends io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.IngressControllerSpec,io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecBuilder>{
  public IngressControllerSpecBuilder() {
    this(false);
  }
  public IngressControllerSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressControllerSpec(), validationEnabled);
  }
  public IngressControllerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressControllerSpec(), validationEnabled);
  }
  public IngressControllerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerSpec instance) {
    this(fluent, instance, false);
  }
  public IngressControllerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientTLS(instance.getClientTLS()); 
    fluent.withDefaultCertificate(instance.getDefaultCertificate()); 
    fluent.withDomain(instance.getDomain()); 
    fluent.withEndpointPublishingStrategy(instance.getEndpointPublishingStrategy()); 
    fluent.withHttpCompression(instance.getHttpCompression()); 
    fluent.withHttpEmptyRequestsPolicy(instance.getHttpEmptyRequestsPolicy()); 
    fluent.withHttpErrorCodePages(instance.getHttpErrorCodePages()); 
    fluent.withHttpHeaders(instance.getHttpHeaders()); 
    fluent.withLogging(instance.getLogging()); 
    fluent.withNamespaceSelector(instance.getNamespaceSelector()); 
    fluent.withNodePlacement(instance.getNodePlacement()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withRouteAdmission(instance.getRouteAdmission()); 
    fluent.withRouteSelector(instance.getRouteSelector()); 
    fluent.withTlsSecurityProfile(instance.getTlsSecurityProfile()); 
    fluent.withTuningOptions(instance.getTuningOptions()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerSpec instance) {
    this(instance,false);
  }
  public IngressControllerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientTLS(instance.getClientTLS()); 
    this.withDefaultCertificate(instance.getDefaultCertificate()); 
    this.withDomain(instance.getDomain()); 
    this.withEndpointPublishingStrategy(instance.getEndpointPublishingStrategy()); 
    this.withHttpCompression(instance.getHttpCompression()); 
    this.withHttpEmptyRequestsPolicy(instance.getHttpEmptyRequestsPolicy()); 
    this.withHttpErrorCodePages(instance.getHttpErrorCodePages()); 
    this.withHttpHeaders(instance.getHttpHeaders()); 
    this.withLogging(instance.getLogging()); 
    this.withNamespaceSelector(instance.getNamespaceSelector()); 
    this.withNodePlacement(instance.getNodePlacement()); 
    this.withReplicas(instance.getReplicas()); 
    this.withRouteAdmission(instance.getRouteAdmission()); 
    this.withRouteSelector(instance.getRouteSelector()); 
    this.withTlsSecurityProfile(instance.getTlsSecurityProfile()); 
    this.withTuningOptions(instance.getTuningOptions()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.IngressControllerSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerSpec build() {
    IngressControllerSpec buildable = new IngressControllerSpec(fluent.getClientTLS(),fluent.getDefaultCertificate(),fluent.getDomain(),fluent.getEndpointPublishingStrategy(),fluent.getHttpCompression(),fluent.getHttpEmptyRequestsPolicy(),fluent.getHttpErrorCodePages(),fluent.getHttpHeaders(),fluent.getLogging(),fluent.getNamespaceSelector(),fluent.getNodePlacement(),fluent.getReplicas(),fluent.getRouteAdmission(),fluent.getRouteSelector(),fluent.getTlsSecurityProfile(),fluent.getTuningOptions(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerSpecBuilder that = (IngressControllerSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.2.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressControllerSpecBuilder extends IngressControllerSpecFluentImpl<IngressControllerSpecBuilder> implements VisitableBuilder<IngressControllerSpec,IngressControllerSpecBuilder>{
  public IngressControllerSpecBuilder() {
    this(false);
  }
  public IngressControllerSpecBuilder(Boolean validationEnabled) {
    this(new IngressControllerSpec(), validationEnabled);
  }
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressControllerSpec(), validationEnabled);
  }
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent,IngressControllerSpec instance) {
    this(fluent, instance, false);
  }
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent,IngressControllerSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClientTLS(instance.getClientTLS()); 
    fluent.withDefaultCertificate(instance.getDefaultCertificate()); 
    fluent.withDomain(instance.getDomain()); 
    fluent.withEndpointPublishingStrategy(instance.getEndpointPublishingStrategy()); 
    fluent.withHttpCompression(instance.getHttpCompression()); 
    fluent.withHttpEmptyRequestsPolicy(instance.getHttpEmptyRequestsPolicy()); 
    fluent.withHttpErrorCodePages(instance.getHttpErrorCodePages()); 
    fluent.withHttpHeaders(instance.getHttpHeaders()); 
    fluent.withLogging(instance.getLogging()); 
    fluent.withNamespaceSelector(instance.getNamespaceSelector()); 
    fluent.withNodePlacement(instance.getNodePlacement()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withRouteAdmission(instance.getRouteAdmission()); 
    fluent.withRouteSelector(instance.getRouteSelector()); 
    fluent.withTlsSecurityProfile(instance.getTlsSecurityProfile()); 
    fluent.withTuningOptions(instance.getTuningOptions()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerSpecBuilder(IngressControllerSpec instance) {
    this(instance,false);
  }
  public IngressControllerSpecBuilder(IngressControllerSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withClientTLS(instance.getClientTLS()); 
    this.withDefaultCertificate(instance.getDefaultCertificate()); 
    this.withDomain(instance.getDomain()); 
    this.withEndpointPublishingStrategy(instance.getEndpointPublishingStrategy()); 
    this.withHttpCompression(instance.getHttpCompression()); 
    this.withHttpEmptyRequestsPolicy(instance.getHttpEmptyRequestsPolicy()); 
    this.withHttpErrorCodePages(instance.getHttpErrorCodePages()); 
    this.withHttpHeaders(instance.getHttpHeaders()); 
    this.withLogging(instance.getLogging()); 
    this.withNamespaceSelector(instance.getNamespaceSelector()); 
    this.withNodePlacement(instance.getNodePlacement()); 
    this.withReplicas(instance.getReplicas()); 
    this.withRouteAdmission(instance.getRouteAdmission()); 
    this.withRouteSelector(instance.getRouteSelector()); 
    this.withTlsSecurityProfile(instance.getTlsSecurityProfile()); 
    this.withTuningOptions(instance.getTuningOptions()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  IngressControllerSpecFluent<?> fluent;
  Boolean validationEnabled;
  public IngressControllerSpec build() {
    IngressControllerSpec buildable = new IngressControllerSpec(fluent.getClientTLS(),fluent.getDefaultCertificate(),fluent.getDomain(),fluent.getEndpointPublishingStrategy(),fluent.getHttpCompression(),fluent.getHttpEmptyRequestsPolicy(),fluent.getHttpErrorCodePages(),fluent.getHttpHeaders(),fluent.getLogging(),fluent.getNamespaceSelector(),fluent.getNodePlacement(),fluent.getReplicas(),fluent.getRouteAdmission(),fluent.getRouteSelector(),fluent.getTlsSecurityProfile(),fluent.getTuningOptions(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
